@@ -196,7 +196,7 @@ pub fn error(string: &str, suggestion: Option<&str>) {
             eprintln!("  {} {}", Paint::cyan("Suggestion:"), suggestion);
         }
         None => {
-            eprintln!("{} {}", Paint::red("Error:"), string);
+            eprintln!("{} {}", Paint::red("Error:").bold(), string);
         }
     }
 }
@@ -205,11 +205,11 @@ pub fn error(string: &str, suggestion: Option<&str>) {
 pub fn warning(string: &str, suggestion: Option<&str>) {
     match suggestion {
         Some(suggestion) => {
-            eprintln!("{} {}", Paint::yellow("Error:").bold(), string);
+            eprintln!("{} {}", Paint::yellow("Warning:").bold(), string);
             eprintln!("  {} {}", Paint::cyan("Suggestion:"), suggestion);
         }
         None => {
-            eprintln!("{} {}", Paint::yellow("Error:"), string);
+            eprintln!("{} {}", Paint::yellow("Warning:").bold(), string);
         }
     }
 }
